from django.apps import AppConfig


class EnumerationConfig(AppConfig):
    name = "enumeration"
